@@ -2,8 +2,11 @@
 # -*- coding: utf-8 -*-
 
 from optparse import OptionParser
+from pathlib import Path
 from sys import exit, stderr
 
+from ycontract import disable_contract
+
 from exclock import __VERSION__
 from exclock.mains.play_clock_main import main as play_clock_main
 from exclock.mains.show_list_main import main as show_list_main
@@ -49,9 +52,13 @@ def get_option_parser():
 
 
 def main() -> None:
+    if not (Path(__file__).parent.parent / ".git").exists():
+        disable_contract()
+
     if not executable("xmessage") and not executable("terminal-notifier"):
         print("both xmessage and terminal-notifier not found.", file=stderr)
         exit(1)
+
     if not executable("mplayer"):
         print("mplayer not found.", file=stderr)
         exit(1)
