@@ -52,10 +52,17 @@ def get_ring_filename(ring_sound_filename: Optional[str]) -> str:
 
 def main(opt: optparse.Values, args: List[str]) -> None:
     spend_sec = get_spend_sec(opt.time)
+    is_specific_time = is_specific_time_str(opt.time)
+
     if spend_sec is None:
         print("time format is illegal.", file=stderr)
         exit(1)
 
+    if is_specific_time:
+        hour, min_, sec = get_specific_time_from_str(opt.time)
+        sec_str = "" if sec == 0 else f":{sec:02d}"
+        print(f"sleep until {hour:02d}:{min_:02d}{sec_str}")
+
     try:
         ring_sound_filename = get_ring_filename(opt.ring_filename)
         if not Path(ring_sound_filename).exists():
@@ -70,4 +77,5 @@ def main(opt: optparse.Values, args: List[str]) -> None:
     except KeyboardInterrupt:
         ...
     finally:
+        print()
         print('bye')
