@@ -10,7 +10,6 @@ from sys import stdout
 from time import sleep as time_sleep
 from typing import List, Optional, Tuple
 
-from tqdm import tqdm
 from ycontract import contract
 
 DEFAULT_RING_FILENAME = "ring.mp3"
@@ -178,10 +177,14 @@ def notify_all(
     out_io=stdout,
     cmd_io=None,
 ) -> None:
-    tqdm_f = (lambda i: i) if spend_sec == 0 else lambda i: tqdm(
-        i, bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} ")
-    for _ in tqdm_f(range(spend_sec)):
-        time_sleep(1)
+    if spend_sec == 0:
+        time_sleep(spend_sec)
+    else:
+        for i in range(spend_sec):
+            time_sleep(1)
+            percent = int(100 * i / spend_sec)
+            print(f"\r  {i} / {spend_sec}    {percent}%", end="")
+        print()
 
     if not is_first:
         notify(title=title, message=message, cmd_io=cmd_io)
